@@ -2,7 +2,7 @@
 /*
   Copyright(C) 2010 Tetsuro IKEDA
   Copyright(C) 2010-2013 Kentoku SHIBA
-  Copyright(C) 2011-2018 Kouhei Sutou <kou@clear-code.com>
+  Copyright(C) 2011-2019 Kouhei Sutou <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -447,6 +447,7 @@ struct ha_index_option_struct
   const char *normalizer;
   const char *token_filters;
   const char *flags;
+  const char *lexicon;
 };
 #endif
 
@@ -917,21 +918,20 @@ private:
   grn_obj *find_column_type(Field *field, MRN_SHARE *mrn_share, int i,
                             int error_code);
   void set_tokenizer(grn_obj *lexicon, KEY *key);
-  void set_tokenizer(grn_obj *lexicon, const char *name);
+  void set_tokenizer(grn_obj *lexicon,
+                     const char *name,
+                     size_t name_length);
   bool have_custom_normalizer(KEY *key) const;
-  void set_normalizer(grn_obj *lexicon, KEY *normalizer);
+  void set_normalizer(grn_obj *lexicon, KEY *key);
   void set_normalizer(grn_obj *lexicon,
                       KEY *key,
                       const char *normalizer,
                       size_t normalizer_length);
   bool find_index_column_flags(KEY *key, grn_column_flags *index_column_flags);
-  bool find_token_filters(KEY *key, grn_obj *token_filters);
-  bool find_token_filters_put(grn_obj *token_filters,
-                              const char *token_filter_name,
-                              int token_filter_name_length);
-  bool find_token_filters_fill(grn_obj *token_filters,
-                               const char *token_filter_names,
-                               int token_filter_name_length);
+  void set_token_filters(grn_obj *lexicon, KEY *key);
+  void set_token_filters(grn_obj *lexicon,
+                         const char *token_filters,
+                         size_t token_filters_length);
   int wrapper_get_record(uchar *buf, const uchar *key);
   int wrapper_get_next_geo_record(uchar *buf);
   int storage_get_next_record(uchar *buf);
