@@ -18,9 +18,10 @@
 # License along with this library; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
-export BASE_DIR="$(cd $(dirname $0); pwd)"
-top_dir="$BASE_DIR/.."
-mroonga_test_dir="${top_dir}/mysql-test/mroonga"
+: ${top_build_dir:="$(cd .; pwd)"}
+source_dir="$(cd $(dirname $0); pwd)"
+top_source_dir="${source_dir}/.."
+mroonga_test_dir="${top_source_dir}/mysql-test/mroonga"
 
 n_processors=1
 case `uname` in
@@ -40,12 +41,12 @@ if [ "$NO_MAKE" != "yes" ]; then
   if [ -n "$n_processors" ]; then
     MAKE_ARGS="-j${n_processors}"
   fi
-  make $MAKE_ARGS -C $top_dir > /dev/null || exit 1
+  make $MAKE_ARGS -C ${top_build_dir} > /dev/null || exit 1
 fi
 
-. "${top_dir}/config.sh"
+. "${top_build_dir}/config.sh"
 
-bundled_groonga_normalizer_mysql_dir="${top_dir}/vendor/groonga/vendor/plugins/groonga-normalizer-mysql"
+bundled_groonga_normalizer_mysql_dir="${top_source_dir}/vendor/groonga/vendor/plugins/groonga-normalizer-mysql"
 if [ -d "${bundled_groonga_normalizer_mysql_dir}" ]; then
   GRN_PLUGINS_DIR="${bundled_groonga_normalizer_mysql_dir}"
   export GRN_PLUGINS_DIR
@@ -70,32 +71,22 @@ source_test_suites_dir="${source_mysql_test_dir}/suite"
 source_test_include_dir="${source_mysql_test_dir}/include"
 build_test_suites_dir="${build_mysql_test_dir}/suite"
 build_test_include_dir="${build_mysql_test_dir}/include"
-case "${MYSQL_VERSION}" in
-  5.1.*)
-    plugins_dir="${MYSQL_BUILD_DIR}/lib/mysql/plugin"
-    if [ ! -d "${build_test_suites_dir}" ]; then
-      mkdir -p "${build_test_suites_dir}"
+if [ ! -d "${build_test_suites_dir}" ]; then
+  ln -s "${source_test_suites_dir}" "${build_test_suites_dir}"
+fi
+if [ "${mariadb}" = "yes" ]; then
+  if [ "${MRN_BUNDLED}" != "TRUE" ]; then
+    mariadb_mroonga_plugin_dir="${MYSQL_BUILD_DIR}/plugin/mroonga"
+    if [ ! -e "${mariadb_mroonga_plugin_dir}" ]; then
+      ln -s "${top_build_dir}" "${mariadb_mroonga_plugin_dir}"
     fi
-    ;;
-  *)
-    if [ ! -d "${build_test_suites_dir}" ]; then
-      ln -s "${source_test_suites_dir}" "${build_test_suites_dir}"
-    fi
-    if [ "${mariadb}" = "yes" ]; then
-      if [ "${MRN_BUNDLED}" != "TRUE" ]; then
-	mariadb_mroonga_plugin_dir="${MYSQL_BUILD_DIR}/plugin/mroonga"
-	if [ ! -e "${mariadb_mroonga_plugin_dir}" ]; then
-	  ln -s "${top_dir}" "${mariadb_mroonga_plugin_dir}"
-	fi
-      fi
-      plugins_dir=
-    elif [ "${percona}" = "yes" ]; then
-      plugins_dir="${MYSQL_SOURCE_DIR}/lib/mysql/plugin"
-    else
-      plugins_dir="${MYSQL_SOURCE_DIR}/lib/plugin"
-    fi
-    ;;
-esac
+  fi
+  plugins_dir=
+elif [ "${percona}" = "yes" ]; then
+  plugins_dir="${MYSQL_SOURCE_DIR}/lib/mysql/plugin"
+else
+  plugins_dir="${MYSQL_SOURCE_DIR}/lib/plugin"
+fi
 
 same_link_p()
 {
@@ -159,14 +150,14 @@ done
 cd -
 
 if [ -n "${plugins_dir}" ]; then
-  if [ -d "${top_dir}/.libs" ]; then
-    make -C ${top_dir} \
+  if [ -d "${top_build_dir}/.libs" ]; then
+    make -C ${top_build_dir} \
 	 install-pluginLTLIBRARIES \
 	 plugindir=${plugins_dir} > /dev/null || \
       exit 1
   else
     mkdir -p "${plugins_dir}"
-    cp "${top_dir}/ha_mroonga.so" "${plugins_dir}" || exit 1
+    cp "${top_build_dir}/ha_mroonga.so" "${plugins_dir}" || exit 1
   fi
 fi
 
