@@ -1,6 +1,6 @@
 /* -*- c-basic-offset: 2; indent-tabs-mode: nil -*- */
 /*
-  Copyright(C) 2015-2016 Kouhei Sutou <kou@clear-code.com>
+  Copyright(C) 2015-2017 Kouhei Sutou <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -27,6 +27,8 @@
 #include <mrn_database_manager.hpp>
 #include <mrn_context_pool.hpp>
 #include <mrn_variables.hpp>
+#include <mrn_query_parser.hpp>
+#include <mrn_current_thread.hpp>
 
 MRN_BEGIN_DECLS
 
@@ -47,7 +49,7 @@ typedef struct st_mrn_snippet_html_info
   } query_mode;
 } mrn_snippet_html_info;
 
-static my_bool mrn_snippet_html_prepare(mrn_snippet_html_info *info,
+static mrn_bool mrn_snippet_html_prepare(mrn_snippet_html_info *info,
                                         UDF_ARGS *args,
                                         char *message,
                                         grn_obj **snippet)
@@ -62,7 +64,6 @@ static my_bool mrn_snippet_html_prepare(mrn_snippet_html_info *info,
   const char *close_tag = "</span>";
   grn_snip_mapping *mapping = GRN_SNIP_MAPPING_HTML_ESCAPE;
   grn_obj *expr = NULL;
-  grn_rc rc;
   String *result_str = &(info->result_str);
 
   *snippet = NULL;
@@ -116,17 +117,13 @@ static my_bool mrn_snippet_html_prepare(mrn_snippet_html_info *info,
       goto error;
     }
 
-    // TODO: Use the same flags get logic in
-    // ha_mroonga::generic_ft_init_ext_parse_pragma().
-    grn_expr_flags flags = GRN_EXPR_SYNTAX_QUERY | GRN_EXPR_ALLOW_LEADING_NOT;
-    rc = grn_expr_parse(info->ctx,
-                        expr,
-                        args->args[1],
-                        args->lengths[1],
-                        info->query_mode.default_column,
-                        GRN_OP_MATCH,
-                        GRN_OP_OR,
-                        flags);
+    mrn::QueryParser query_parser(info->ctx,
+                                  current_thd,
+                                  expr,
+                                  info->query_mode.default_column,
+                                  0,
+                                  NULL);
+    grn_rc rc = query_parser.parse(args->args[1], args->lengths[1]);
     if (rc != GRN_SUCCESS) {
       if (message) {
         snprintf(message, MYSQL_ERRMSG_SIZE,
@@ -158,10 +155,10 @@ static my_bool mrn_snippet_html_prepare(mrn_snippet_html_info *info,
       if (!args->args[i]) {
         continue;
       }
-      rc = grn_snip_add_cond(ctx, *snippet,
-                             args->args[i], args->lengths[i],
-                             NULL, 0,
-                             NULL, 0);
+      grn_rc rc = grn_snip_add_cond(ctx, *snippet,
+                                    args->args[i], args->lengths[i],
+                                    NULL, 0,
+                                    NULL, 0);
       if (rc != GRN_SUCCESS) {
         if (message) {
           snprintf(message, MYSQL_ERRMSG_SIZE,
@@ -175,7 +172,7 @@ static my_bool mrn_snippet_html_prepare(mrn_snippet_html_info *info,
   }
 
   result_str->set_charset(system_charset_info);
-  DBUG_RETURN(FALSE);
+  DBUG_RETURN(false);
 
 error:
   if (expr) {
@@ -184,10 +181,10 @@ error:
   if (*snippet) {
     grn_obj_close(ctx, *snippet);
   }
-  DBUG_RETURN(TRUE);
+  DBUG_RETURN(true);
 }
 
-MRN_API my_bool mroonga_snippet_html_init(UDF_INIT *init,
+MRN_API mrn_bool mroonga_snippet_html_init(UDF_INIT *init,
                                           UDF_ARGS *args,
                                           char *message)
 {
@@ -270,21 +267,21 @@ MRN_API my_bool mroonga_snippet_html_init(UDF_INIT *init,
     }
   }
 
-  info->query_mode.used = FALSE;
+  info->query_mode.used = false;
 
   if (args->arg_count == 2 &&
       args->attribute_lengths[1] == strlen("query") &&
       strncmp(args->attributes[1], "query", strlen("query")) == 0) {
-    info->query_mode.used = TRUE;
+    info->query_mode.used = true;
     info->query_mode.table = NULL;
     info->query_mode.default_column = NULL;
   }
 
   {
-    bool all_keywords_are_constant = TRUE;
+    bool all_keywords_are_constant = true;
     for (unsigned int i = 1; i < args->arg_count; ++i) {
       if (!args->args[i]) {
-        all_keywords_are_constant = FALSE;
+        all_keywords_are_constant = false;
         break;
       }
     }
@@ -300,7 +297,7 @@ MRN_API my_bool mroonga_snippet_html_init(UDF_INIT *init,
 
   init->ptr = (char *)info;
 
-  DBUG_RETURN(FALSE);
+  DBUG_RETURN(false);
 
 error:
   if (info) {
@@ -310,7 +307,7 @@ error:
     mrn_context_pool->release(info->ctx);
     my_free(info);
   }
-  DBUG_RETURN(TRUE);
+  DBUG_RETURN(true);
 }
 
 MRN_API char *mroonga_snippet_html(UDF_INIT *init,
